@@ -113,8 +113,13 @@ struct msgs {
      */
     seqset_t attrstats;
 
-    int	lowoff;			  /* low element in msgstats[]   */
-    int	hghoff;			  /* hgh element in msgstats[]   */
+    /*
+     * These represent the lowest and highest possible
+     * message numbers we can put in the message status
+     * area, without calling folder_realloc().
+     */
+    int	lowoff;
+    int	hghoff;
 
     /*
      * This is an array of seqset_t which we allocate dynamically.
@@ -127,46 +132,45 @@ struct msgs {
 };
 
 /*
- * Amount of space to allocate for msgstats.
- * Currently, we just allocate the array to have
- * space for messages 1 to hi (slot for 0 is unused).
+ * Amount of space to allocate for msgstats.  Allocate
+ * the array to have space for messages numbers lo to hi.
  */
-#define MSGSTATSIZE(mp,lo,hi) ((size_t) (((hi) + 1) * sizeof(*mp->msgstats)))
+#define MSGSTATSIZE(mp,lo,hi) ((size_t) (((hi) - (lo) + 1) * sizeof(*(mp)->msgstats)))
 
 /*
  * macros for message and sequence manipulation
  */
-#define clear_msg_flags(mp,msgnum) ((mp)->msgstats[msgnum] = 0)
+#define clear_msg_flags(mp,msgnum) ((mp)->msgstats[(msgnum) - mp->lowoff] = 0)
 #define copy_msg_flags(mp,i,j) \
-	((mp)->msgstats[i] = (mp)->msgstats[j])
-#define get_msg_flags(mp,ptr,msgnum)  (*(ptr) = (mp)->msgstats[msgnum])
-#define set_msg_flags(mp,ptr,msgnum)  ((mp)->msgstats[msgnum] = *(ptr))
+	((mp)->msgstats[(i) - mp->lowoff] = (mp)->msgstats[(j) - mp->lowoff])
+#define get_msg_flags(mp,ptr,msgnum)  (*(ptr) = (mp)->msgstats[(msgnum) - mp->lowoff])
+#define set_msg_flags(mp,ptr,msgnum)  ((mp)->msgstats[(msgnum) - mp->lowoff] = *(ptr))
 
-#define does_exist(mp,msgnum)     ((mp)->msgstats[msgnum] & EXISTS)
-#define unset_exists(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~EXISTS)
-#define set_exists(mp,msgnum)     ((mp)->msgstats[msgnum] |= EXISTS)
+#define does_exist(mp,msgnum)     ((mp)->msgstats[(msgnum) - mp->lowoff] & EXISTS)
+#define unset_exists(mp,msgnum)   ((mp)->msgstats[(msgnum) - mp->lowoff] &= ~EXISTS)
+#define set_exists(mp,msgnum)     ((mp)->msgstats[(msgnum) - mp->lowoff] |= EXISTS)
 
-#define is_selected(mp,msgnum)    ((mp)->msgstats[msgnum] & SELECTED)
-#define unset_selected(mp,msgnum) ((mp)->msgstats[msgnum] &= ~SELECTED)
-#define set_selected(mp,msgnum)   ((mp)->msgstats[msgnum] |= SELECTED)
+#define is_selected(mp,msgnum)    ((mp)->msgstats[(msgnum) - mp->lowoff] & SELECTED)
+#define unset_selected(mp,msgnum) ((mp)->msgstats[(msgnum) - mp->lowoff] &= ~SELECTED)
+#define set_selected(mp,msgnum)   ((mp)->msgstats[(msgnum) - mp->lowoff] |= SELECTED)
 
-#define is_select_empty(mp,msgnum) ((mp)->msgstats[msgnum] & SELECT_EMPTY)
+#define is_select_empty(mp,msgnum) ((mp)->msgstats[(msgnum) - mp->lowoff] & SELECT_EMPTY)
 #define set_select_empty(mp,msgnum) \
-	((mp)->msgstats[msgnum] |= SELECT_EMPTY)
+	((mp)->msgstats[(msgnum) - mp->lowoff] |= SELECT_EMPTY)
 
-#define is_unseen(mp,msgnum)      ((mp)->msgstats[msgnum] & SELECT_UNSEEN)
-#define unset_unseen(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~SELECT_UNSEEN)
-#define set_unseen(mp,msgnum)     ((mp)->msgstats[msgnum] |= SELECT_UNSEEN)
+#define is_unseen(mp,msgnum)      ((mp)->msgstats[(msgnum) - mp->lowoff] & SELECT_UNSEEN)
+#define unset_unseen(mp,msgnum)   ((mp)->msgstats[(msgnum) - mp->lowoff] &= ~SELECT_UNSEEN)
+#define set_unseen(mp,msgnum)     ((mp)->msgstats[(msgnum) - mp->lowoff] |= SELECT_UNSEEN)
 
 /* for msh only */
-#define set_deleted(mp,msgnum)    ((mp)->msgstats[msgnum] |= DELETED)
+#define set_deleted(mp,msgnum)    ((mp)->msgstats[(msgnum) - mp->lowoff] |= DELETED)
 
 #define in_sequence(mp,seqnum,msgnum) \
-           ((mp)->msgstats[msgnum] & (1 << (FFATTRSLOT + seqnum)))
+           ((mp)->msgstats[(msgnum) - mp->lowoff] & (1 << (FFATTRSLOT + seqnum)))
 #define clear_sequence(mp,seqnum,msgnum) \
-           ((mp)->msgstats[msgnum] &= ~(1 << (FFATTRSLOT + seqnum)))
+           ((mp)->msgstats[(msgnum) - mp->lowoff] &= ~(1 << (FFATTRSLOT + seqnum)))
 #define add_sequence(mp,seqnum,msgnum) \
-           ((mp)->msgstats[msgnum] |= (1 << (FFATTRSLOT + seqnum)))
+           ((mp)->msgstats[(msgnum) - mp->lowoff] |= (1 << (FFATTRSLOT + seqnum)))
 
 #define is_seq_private(mp,seqnum) \
            ((mp)->attrstats & (1 << (FFATTRSLOT + seqnum)))
@@ -229,7 +233,11 @@ extern char *msg_delim;		/*  .. */
 /*
  * miscellaneous macros
  */
-#define	pidXwait(id,cp)	pidstatus (pidwait (id, NOTOK), stdout, cp)
+#define	pidXwait(pid,cp) pidstatus (pidwait (pid, NOTOK), stdout, cp)
+
+#ifndef max
+# define max(a,b) ((a) > (b) ? (a) : (b))
+#endif
 
 #ifndef min
 # define min(a,b) ((a) < (b) ? (a) : (b))
