@@ -58,7 +58,7 @@ cpydgst (int in, int out, char *ifile, char *ofile)
 	    }
 	}
 
-    if (i == NOTOK)
+    if (i == -1)
 	adios (ifile, "error reading");
     flush();
 }
