@@ -1,6 +1,7 @@
 
 /*
- * folder_pack.c -- pack the messages in a folder
+ * folder_pack.c -- pack (renumber) the messages in a folder
+ *               -- into a contiguous range from 1 to n.
  *
  * $Id$
  */
@@ -21,6 +22,12 @@ folder_pack (struct msgs **mpp, int verbose)
 
     mp = *mpp;
 
+    /*
+     * Just return if folder is empty.
+     */
+    if (mp->nummsg == 0)
+	return 0;
+
     /*
      * Make sure we have message status space allocated
      * for all numbers from 1 to current high message.
@@ -57,10 +64,10 @@ folder_pack (struct msgs **mpp, int verbose)
 	    hole++;
 	}
     }
-    if (mp->nummsg > 0) {
-	mp->lowmsg = 1;
-	mp->hghmsg = hole - 1;
-    }
+
+    /* record the new number for high/low message */
+    mp->lowmsg = 1;
+    mp->hghmsg = hole - 1;
 
     return 0;
 }
