@@ -22,11 +22,13 @@ folder_realloc (struct msgs *mp, int lo, int hi)
 
     /* sanity checks */
     if (lo < 1)
-	adios (NULL, "BUG: calling folder_realloc with lo < 1");
-    if (lo > mp->lowmsg)
-	adios (NULL, "BUG: calling folder_realloc with lo > mp->lowmsg");
-    if (hi < mp->hghmsg)
-	adios (NULL, "BUG: calling folder_realloc with hi < mp->hghmsg");
+	adios (NULL, "BUG: called folder_realloc with lo (%d) < 1", lo);
+    if (hi < 1)
+	adios (NULL, "BUG: called folder_realloc with hi (%d) < 1", hi);
+    if (mp->lowmsg > 0 && lo > mp->lowmsg)
+	adios (NULL, "BUG: called folder_realloc with lo (%d) > mp->lowmsg (%d)", lo, mp->lowmsg);
+    if (mp->hghmsg > 0 && hi < mp->hghmsg)
+	adios (NULL, "BUG: called folder_realloc with hi (%d) < mp->hghmsg (%d)", hi, mp->hghmsg);
 
     /* Check if we really need to reallocate anything */
     if (lo == mp->lowoff && hi == mp->hghoff)
