@@ -320,7 +320,8 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		cnt = (long) iob->_IO_read_end - (long) iob->_IO_read_ptr;
 		bp = (unsigned char *) --iob->_IO_read_ptr;
 #else
-		cnt = iob->_cnt++; bp = (unsigned char *) --iob->_ptr;
+		cnt = iob->_cnt++;
+		bp = (unsigned char *) --iob->_ptr;
 #endif
 		c = cnt < i ? cnt : i;
 		while ((ep = locc( c, bp, '\n' ))) {
@@ -330,18 +331,20 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		    if ((j = *++ep) != ' ' && j != '\t') {
 #ifdef LINUX_STDIO
 			j = ep - (unsigned char *) iob->_IO_read_ptr;
-			memcpy( cp, iob->_IO_read_ptr, j);
+			memcpy (cp, iob->_IO_read_ptr, j);
 			iob->_IO_read_ptr = ep;
 #else
 			j = ep - (unsigned char *) iob->_ptr;
-			memcpy( cp, iob->_ptr, j);
-			iob->_ptr = ep; iob->_cnt -= j;
+			memcpy (cp, iob->_ptr, j);
+			iob->_ptr = ep;
+			iob->_cnt -= j;
 #endif
 			cp += j;
 			state = FLD;
 			goto finish;
 		    }
-		    c -= ep - bp; bp = ep;
+		    c -= ep - bp;
+		    bp = ep;
 		}
 		/*
 		 * end of input or dest buffer - copy what we've found.
@@ -353,13 +356,15 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		c += bp - (unsigned char *) iob->_ptr;
 		memcpy( cp, iob->_ptr, c);
 #endif
-		i -= c; cp += c;
+		i -= c;
+		cp += c;
 		if (i <= 0) {
 		    /* the dest buffer is full */
 #ifdef LINUX_STDIO
 		    iob->_IO_read_ptr += c;
 #else
-		    iob->_cnt -= c; iob->_ptr += c;
+		    iob->_cnt -= c;
+		    iob->_ptr += c;
 #endif
 		    state = FLDPLUS;
 		    break;
@@ -408,7 +413,8 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	    bp = (unsigned char *) --iob->_IO_read_ptr;
 	    cnt = (long) iob->_IO_read_end - (long) iob->_IO_read_ptr;
 #else
-	    bp = (unsigned char *) --iob->_ptr; cnt = ++iob->_cnt;
+	    bp = (unsigned char *) --iob->_ptr;
+	    cnt = ++iob->_cnt;
 #endif
 	    c = (cnt < i ? cnt : i);
 	    if (msg_style != MS_DEFAULT && c > 1) {
@@ -482,7 +488,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	default: 
 	    adios (NULL, "m_getfld() called with bogus state of %d", state);
     }
-finish:;
+finish:
     *cp = 0;
     msg_count = cp - buf;
     return (state);
