@@ -34,7 +34,7 @@ m_putenv (char *name, char *value)
 	    return 0;
 	}
 
-    if (!(nep = (char **) malloc ((size_t) ((i + 2) * sizeof *nep))))
+    if (!(nep = (char **) malloc ((size_t) ((i + 2) * sizeof(*nep)))))
 	return 1;
 
     for (ep = environ, i = 0; *ep; nep[i++] = *ep++)
