@@ -24,7 +24,8 @@ void
 seq_read (struct msgs *mp)
 {
     int alen, i, j, plen, state;
-    char *cp, name[NAMESZ], field[BUFSIZ * 2];
+    char *cp, seqfile[PATH_MAX];
+    char name[NAMESZ], field[BUFSIZ];
     struct node *np;
     FILE *fp;
 
@@ -42,57 +43,72 @@ seq_read (struct msgs *mp)
      * (*mh_seq == '\0'), then make all sequences private.
      */
     if (mh_seq && *mh_seq != '\0')
-	sprintf (field, "%s/%s", mp->foldpath, mh_seq);
+	snprintf (seqfile, PATH_MAX, "%s/%s", mp->foldpath, mh_seq);
     else
 	goto private_only;
 
     /*
      * read folder's sequences file for public sequences
      */
-    if ((fp = fopen (field, "r"))) {
+    if ((fp = fopen (seqfile, "r"))) {
 	for (state = FLD;;) {
 	    switch (state = m_getfld (state, name, field, sizeof(field), fp)) {
 		case FLD: 
+		case FLDPLUS:
 		case FLDEOF: 
-		    seq_init (mp, getcpy (name), trimcpy (field));
+		    if (state == FLDPLUS) {
+			cp = getcpy (field);
+			while (state == FLDPLUS) {
+			    state = m_getfld (state, name, field, sizeof(field), fp);
+			    cp = add (field, cp);
+			}
+			seq_init (mp, getcpy (name), trimcpy (cp));
+			free (cp);
+		    } else {
+			seq_init (mp, getcpy (name), trimcpy (field));
+		    }
 		    if (state == FLDEOF)
 			break;
 		    continue;
 
 		case BODY: 
 		case BODYEOF: 
-		    adios (NULL, "no blank lines are permitted in %s/%s",
-			   mp->foldpath, mh_seq);	/* fall */
+		    adios (NULL, "no blank lines are permitted in %s", seqfile);
+		    /* fall */
 
 		case FILEEOF:
 		    break;
 
 		default: 
-		    adios (NULL, "%s/%s is poorly formatted", mp->foldpath, mh_seq);
+		    adios (NULL, "%s is poorly formatted", seqfile);
 	    }
 	    break;
 	}
 	fclose (fp);
     }
 
-private_only:;
+private_only:
 
     /*
-     * Scan profile/context list for private sequences
+     * Scan profile/context list for private sequences.
+     *
+     * We search the context list for all keys that look like
+     * "atr-seqname-folderpath", and add them.
      */
     alen = strlen ("atr-");
     plen = strlen (mp->foldpath) + 1;
 
-    for (np = m_defs; np; np = np->n_next)
+    for (np = m_defs; np; np = np->n_next) {
 	if (ssequal ("atr-", np->n_name)
 		&& (j = strlen (np->n_name) - plen) > alen
 		&& *(np->n_name + j) == '-'
 		&& strcmp (mp->foldpath, np->n_name + j + 1) == 0) {
 	    cp = getcpy (np->n_name + alen);
 	    *(cp + j - alen) = '\0';
-	    if ((i = seq_init (mp, cp, getcpy (np->n_field))) != NOTOK)
+	    if ((i = seq_init (mp, cp, getcpy (np->n_field))) != -1)
 		make_seq_private (mp, i);
 	}
+    }
 }
 
 
@@ -112,8 +128,6 @@ seq_init (struct msgs *mp, char *name, char *field)
      */
     is_current = !strcmp (current, name);
 
-    /* if we're going to use UNSEEN, it should be set here! */
-
     /*
      * If we've seen this sequence before, then
      * clear the bit for this sequence from
@@ -130,7 +144,7 @@ seq_init (struct msgs *mp, char *name, char *field)
     if (i >= NUMATTRS) {
 	free (name);
 	free (field);
-	return NOTOK;
+	return -1;
     }
 
     if (mp->msgattrs[i]) {
