@@ -76,7 +76,7 @@ main (int argc, char **argv)
 
 	    case HELPSW: 
 		sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		print_help (buf, switches);
+		print_help (buf, switches, 1);
 		done (1);
 	    case VERSIONSW:
 		print_version(invo_name);
@@ -270,7 +270,7 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
      * structure for all the new messages.
      */
     if ((mp->hghmsg + numburst > mp->hghoff) &&
-	!(mp = folder_realloc (mp, 0, mp->hghmsg + numburst)))
+	!(mp = folder_realloc (mp, mp->lowoff, mp->hghmsg + numburst)))
 	adios (NULL, "unable to allocate folder storage");
     *mpp = mp;
 
