@@ -159,7 +159,7 @@ static struct pair pairs[] = {
     { "Resent-cc",       ADDRFMT },
     { "Resent-Bcc",      ADDRFMT },
     { "Face",            FACEFMT },
-    { NULL,              NULL }
+    { NULL,              0 }
 };
 
 struct triple {
