@@ -334,8 +334,9 @@ main (int argc, char **argv)
 	mp->msgflags |= SEQMOD;
 	seq_save (mp);
     }
+
 #ifdef WHATNOW
-go_to_it: ;
+go_to_it:
 #endif /* WHATNOW */
 
     if ((cp = getenv ("SIGNATURE")) == NULL || *cp == 0)
@@ -398,8 +399,11 @@ go_to_it: ;
 	distfile = NULL;
     }
 
-    if (altmsg == NULL || stat (altmsg, &st) == NOTOK)
-	st.st_mtime = 0, st.st_dev = 0, st.st_ino = 0;
+    if (altmsg == NULL || stat (altmsg, &st) == NOTOK) {
+	st.st_mtime = 0;
+	st.st_dev = 0;
+	st.st_ino = 0;
+    }
     if (pushsw)
 	push ();
 
