@@ -42,14 +42,14 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
     if (nedit)
 	unputenv ("mheditor");
     else
-	m_putenv ("mheditor", ed ? ed : (ed = m_find ("editor")) ? ed : sysed);
+	m_putenv ("mheditor", ed ? ed : (ed = context_find ("editor")) ? ed : sysed);
     sprintf (buffer, "%d", use);
     m_putenv ("mhuse", buffer);
 
     unputenv ("mhmessages");
     unputenv ("mhannotate");
     unputenv ("mhinplace");
-    if (text && mp && !(mp->msgflags & READONLY)) {
+    if (text && mp && !is_readonly(mp)) {
 	found = 0;
 	bp = buffer;
 	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
@@ -73,7 +73,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	}
     }
 
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     fflush (stdout);
 
     if (cwd)
