@@ -67,7 +67,7 @@ main (int argc, char **argv)
     vec[vecp++] = getcpy (m_maildir (""));
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -77,7 +77,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [file]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -121,6 +121,7 @@ main (int argc, char **argv)
 		    vec[vecp++] = cp;
 		    continue;
 	    }
+	}
 	if (msg)
 	    adios (NULL, "only one draft at a time!");
 	else
@@ -185,4 +186,6 @@ main (int argc, char **argv)
 		adios (msg, "unable to rename %s to", backup);
 	    done (status);
     }
+
+    exit (-1);	/* NOT REACHED */
 }
